namespace elm { 
inline ::efl::eolian::return_traits<void>::type Colorselector::color_get( ::efl::eolian::out_traits<int>::type r,  ::efl::eolian::out_traits<int>::type g,  ::efl::eolian::out_traits<int>::type b,  ::efl::eolian::out_traits<int>::type a) const
{
   int __out_param_r = {};
   int __out_param_g = {};
   int __out_param_b = {};
   int __out_param_a = {};
    ::elm_obj_colorselector_color_get(this->_eo_ptr()
      , & __out_param_r
      , & __out_param_g
      , & __out_param_b
      , & __out_param_a);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(r, __out_param_r);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(g, __out_param_g);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(b, __out_param_b);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(a, __out_param_a);
}
inline ::efl::eolian::return_traits<void>::type Colorselector::color_set( ::efl::eolian::in_traits<int>::type r,  ::efl::eolian::in_traits<int>::type g,  ::efl::eolian::in_traits<int>::type b,  ::efl::eolian::in_traits<int>::type a) const
{
    ::elm_obj_colorselector_color_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(r)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(g)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(b)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(a));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Colorselector::palette_name_get() const
{
   const char * __return_value =  ::elm_obj_colorselector_palette_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Colorselector::palette_name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type palette_name) const
{
    ::elm_obj_colorselector_palette_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(palette_name));
}
inline ::efl::eolian::return_traits<Elm_Colorselector_Mode>::type Colorselector::mode_get() const
{
   Elm_Colorselector_Mode __return_value =  ::elm_obj_colorselector_mode_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Colorselector_Mode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Colorselector::mode_set( ::efl::eolian::in_traits<Elm_Colorselector_Mode>::type mode) const
{
    ::elm_obj_colorselector_mode_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Colorselector_Mode,  ::efl::eolian::in_traits<Elm_Colorselector_Mode>::type>(mode));
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type Colorselector::palette_items_get() const
{
   const Eina_List * __return_value =  ::elm_obj_colorselector_palette_items_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Colorselector::palette_selected_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_colorselector_palette_selected_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Colorselector::palette_color_add( ::efl::eolian::in_traits<int>::type r,  ::efl::eolian::in_traits<int>::type g,  ::efl::eolian::in_traits<int>::type b,  ::efl::eolian::in_traits<int>::type a) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_colorselector_palette_color_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(r)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(g)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(b)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(a));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Colorselector::palette_clear() const
{
    ::elm_obj_colorselector_palette_clear(this->_eo_ptr());
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<void>::type Colorselector::color_get( ::efl::eolian::out_traits<int>::type r,  ::efl::eolian::out_traits<int>::type g,  ::efl::eolian::out_traits<int>::type b,  ::efl::eolian::out_traits<int>::type a) const
{
   int __out_param_r = {};
   int __out_param_g = {};
   int __out_param_b = {};
   int __out_param_a = {};
    ::elm_obj_colorselector_color_get(this->_eo_ptr()
      , & __out_param_r
      , & __out_param_g
      , & __out_param_b
      , & __out_param_a);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(r, __out_param_r);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(g, __out_param_g);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(b, __out_param_b);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(a, __out_param_a);
}
inline ::efl::eolian::return_traits<void>::type Colorselector::color_set( ::efl::eolian::in_traits<int>::type r,  ::efl::eolian::in_traits<int>::type g,  ::efl::eolian::in_traits<int>::type b,  ::efl::eolian::in_traits<int>::type a) const
{
    ::elm_obj_colorselector_color_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(r)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(g)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(b)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(a));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Colorselector::palette_name_get() const
{
   const char * __return_value =  ::elm_obj_colorselector_palette_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Colorselector::palette_name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type palette_name) const
{
    ::elm_obj_colorselector_palette_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(palette_name));
}
inline ::efl::eolian::return_traits<Elm_Colorselector_Mode>::type Colorselector::mode_get() const
{
   Elm_Colorselector_Mode __return_value =  ::elm_obj_colorselector_mode_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Colorselector_Mode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Colorselector::mode_set( ::efl::eolian::in_traits<Elm_Colorselector_Mode>::type mode) const
{
    ::elm_obj_colorselector_mode_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Colorselector_Mode,  ::efl::eolian::in_traits<Elm_Colorselector_Mode>::type>(mode));
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type Colorselector::palette_items_get() const
{
   const Eina_List * __return_value =  ::elm_obj_colorselector_palette_items_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Colorselector::palette_selected_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_colorselector_palette_selected_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Colorselector::palette_color_add( ::efl::eolian::in_traits<int>::type r,  ::efl::eolian::in_traits<int>::type g,  ::efl::eolian::in_traits<int>::type b,  ::efl::eolian::in_traits<int>::type a) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_colorselector_palette_color_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(r)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(g)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(b)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(a));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Colorselector::palette_clear() const
{
    ::elm_obj_colorselector_palette_clear(this->_eo_ptr());
}
inline elm::Colorselector::operator ::elm::Colorselector() const { return *static_cast< ::elm::Colorselector const*>(static_cast<void const*>(this)); }
inline elm::Colorselector::operator ::elm::Colorselector&() { return *static_cast< ::elm::Colorselector*>(static_cast<void*>(this)); }
inline elm::Colorselector::operator ::elm::Colorselector const&() const { return *static_cast< ::elm::Colorselector const*>(static_cast<void const*>(this)); }
} }

